@@ -12,8 +12,8 @@
 ;;; License: GPLv3
 ;;
 ;; Created: October 05, 2016
-;; Package-Version: 20260218.10
-;; Package-Revision: 64897400191f
+;; Package-Version: 20260221.1336
+;; Package-Revision: 13fa459e8d60
 ;; Keywords: startup, screen, tools, dashboard
 ;; Package-Requires: ((emacs "27.1"))
 
@@ -32,8 +32,9 @@
 ;;
 ;;; Externals
 
-(declare-function bookmark-get-filename "ext:bookmark.el")
 (declare-function bookmark-all-names "ext:bookmark.el")
+(declare-function bookmark-get-filename "ext:bookmark.el")
+(declare-function bookmark-delete "ext:bookmark.el")
 (declare-function dashboard-ls--dirs "ext:dashboard-ls.el")
 (declare-function dashboard-ls--files "ext:dashboard-ls.el")
 (declare-function page-break-lines-mode "ext:page-break-lines.el")
@@ -429,7 +430,9 @@ Optional argument ARGS adviced function arguments."
 
 (defun dashboard-remove-item-bookmarks ()
   "Remove a bookmarks from `bookmark-alist'."
-  (interactive))  ; TODO: ..
+  (interactive)
+  (let ((bookmark-name (get-text-property (point) 'dashboard-bookmarks-name)))
+    (bookmark-delete bookmark-name)))
 
 (defun dashboard-remove-item-agenda ()
   "Remove an agenda from `org-agenda-files'."
